==> mx-packageinstaller-pkglist_21.09.03mx21.tar.xz: all/qt5_dev_env.pm <==
<?xml version="1.0"?>
<app>

<category>
Development
</category>

<name>
QT5 Dev Enviroment
</name>

<description>
   <am>QT5 Development Environment</am>
   <ar>QT5 Development Environment</ar>
   <bg>QT5 Development Environment</bg>
   <bn>QT5 Development Environment</bn>
   <ca>Entorn de desenvolupament per QT5</ca>
   <cs>QT5 Development Environment</cs>
   <da>QT5-udviklingsmiljø</da>
   <de>Qt5 Entwicklungsumgebung</de>
   <el>Περιβάλλον ανάπτυξης του QT5</el>
   <en>QT5 Development Environment</en>
   <es>Entorno de desarrollo QT5</es>
   <et>QT5 Development Environment</et>
   <eu>QT5 Development Environment</eu>
   <fa>QT5 Development Environment</fa>
   <fil_PH>QT5 Development Environment</fil_PH>
   <fi>QT5 kehitysympäristö</fi>
   <fr>Environnement de développement QT5</fr>
   <he_IL>QT5 Development Environment</he_IL>
   <hi>QT5 Development Environment</hi>
   <hr>QT5 Development Environment</hr>
   <hu>QT5 Development Environment</hu>
   <id>QT5 Development Environment</id>
   <is>QT5 Development Environment</is>
   <it>Ambiente di sviluppo QT5</it>
   <ja_JP>QT5 Development Environment</ja_JP>
   <ja>QT5 Development Environment</ja>
   <kk>QT5 Development Environment</kk>
   <ko>QT5 Development Environment</ko>
   <lt>QT5 plėtojimo aplinka</lt>
   <mk>QT5 Development Environment</mk>
   <mr>QT5 Development Environment</mr>
   <nb>QT5 Development Environment</nb>
   <nl>QT5 Ontwikkelingsomgeving</nl>
   <pl>środowisko programistyczne QT5</pl>
   <pt_BR>QT5 Development Environment</pt_BR>
   <pt>QT5 Development Environment</pt>
   <ro>QT5 Development Environment</ro>
   <ru>Среда разработки под QT-5</ru>
   <sk>QT5 Development Environment</sk>
   <sl>QT5 razvojno okolje</sl>
   <sq>QT5 Development Environment</sq>
   <sr>QT5 Development Environment</sr>
   <sv>QT5 Utvecklingsmiljö</sv>
   <tr>QT5 Development Environment</tr>
   <uk>QT5 Development Environment</uk>
   <vi>QT5 Development Environment</vi>
   <zh_CN>QT5 Development Environment</zh_CN>
   <zh_TW>QT5 Development Environment</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/009/134/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
qtcreator
qttools5-dev
qttools5-dev-tools
qtdeclarative5-dev-tools
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
qtcreator
qttools5-dev
qttools5-dev-tools
qtdeclarative5-dev-tools
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_21.09.04mx21.tar.xz: all/qt5_dev_env.pm <==
<?xml version="1.0"?>
<app>

<category>
Development
</category>

<name>
QT5 Dev Enviroment
</name>

<description>
   <am>QT5 Development Environment</am>
   <ar>QT5 Development Environment</ar>
   <bg>QT5 Development Environment</bg>
   <bn>QT5 Development Environment</bn>
   <ca>Entorn de desenvolupament per QT5</ca>
   <cs>QT5 Development Environment</cs>
   <da>QT5-udviklingsmiljø</da>
   <de>Qt5 Entwicklungsumgebung</de>
   <el>Περιβάλλον ανάπτυξης του QT5</el>
   <en>QT5 Development Environment</en>
   <es>Entorno de desarrollo QT5</es>
   <et>QT5 Development Environment</et>
   <eu>QT5 Development Environment</eu>
   <fa>QT5 Development Environment</fa>
   <fil_PH>QT5 Development Environment</fil_PH>
   <fi>QT5 kehitysympäristö</fi>
   <fr>Environnement de développement QT5</fr>
   <he_IL>QT5 Development Environment</he_IL>
   <hi>QT5 Development Environment</hi>
   <hr>QT5 Development Environment</hr>
   <hu>QT5 Development Environment</hu>
   <id>QT5 Development Environment</id>
   <is>QT5 Development Environment</is>
   <it>Ambiente di sviluppo QT5</it>
   <ja_JP>QT5 Development Environment</ja_JP>
   <ja>QT5 Development Environment</ja>
   <kk>QT5 Development Environment</kk>
   <ko>QT5 Development Environment</ko>
   <lt>QT5 plėtojimo aplinka</lt>
   <mk>QT5 Development Environment</mk>
   <mr>QT5 Development Environment</mr>
   <nb>QT5 Development Environment</nb>
   <nl>QT5 Ontwikkelingsomgeving</nl>
   <pl>środowisko programistyczne QT5</pl>
   <pt_BR>QT5 Development Environment</pt_BR>
   <pt>QT5 Development Environment</pt>
   <ro>QT5 Development Environment</ro>
   <ru>Среда разработки под QT-5</ru>
   <sk>QT5 Development Environment</sk>
   <sl>QT5 razvojno okolje</sl>
   <sq>QT5 Development Environment</sq>
   <sr>QT5 Development Environment</sr>
   <sv>QT5 Utvecklingsmiljö</sv>
   <tr>QT5 Development Environment</tr>
   <uk>QT5 Development Environment</uk>
   <vi>QT5 Development Environment</vi>
   <zh_CN>QT5 Development Environment</zh_CN>
   <zh_TW>QT5 Development Environment</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/shrine/screenshot/9135/simage/large-8b9e3b4d59744fb8e0d57176f58cc2b4.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
qtcreator
qttools5-dev
qttools5-dev-tools
qtdeclarative5-dev-tools
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
qtcreator
qttools5-dev
qttools5-dev-tools
qtdeclarative5-dev-tools
</uninstall_package_names>
</app>
